<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @since      1.0.0
 *
 * @package    Quick_And_Easy_Seo
 * @subpackage Quick_And_Easy_Seo/public
 */


class Quick_And_Easy_Seo_Public {

	private $plugin_name;
	private $version;
	private $qeseo_options;


	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		/* Get stored options from database */
		$this->qeseo_options = get_option( $this->plugin_name );
		
		/* Remove tags */
		$this->qeseo_remove_unwated_head_tags();

	}
	
	/* Add Robots tag to search, 404 and attachment pages */
	public function qeseo_add_robots_tags(){
		
		$qeseo_follow = "<meta name='Robots' content='noindex,follow' />";
		$qeseo_nofollow = "<meta name='Robots' content='noindex,noFollow' />";
		
		/* Search pages*/
		if( is_search() ){
			
			$qeseo_value = $this->qeseo_options['qeseo_search'];
			if( $qeseo_value == 'ow_follow' ){
				return $qeseo_follow;
			}elseif( $qeseo_value == 'ow_nofollow'  ){
				return $qeseo_nofollow;
			}else{
				return;
			}	
		}
	
		/* 404 pages*/
		if( is_404() ){
			
			$qeseo_value = $this->qeseo_options['qeseo_404'];
			if( $qeseo_value == 'ow_follow' ){
				return $qeseo_follow;
			}elseif( $qeseo_value == 'ow_nofollow'  ){
				return $qeseo_nofollow;
			}else{
				return;
			}							
		}
		
		/* Attachment pages */
		if( is_attachment() ){
			
			$qeseo_value = $this->qeseo_options['qeseo_attachments'];
			if( $qeseo_value == 'ow_follow' ){
				return $qeseo_follow;
			}elseif( $qeseo_value == 'ow_nofollow'  ){
				return $qeseo_nofollow;
			}else{
				return;
			}
		}		
	}	
	
	/* Date archives */
	public function qeseo_robots_tag_archives(){
		
		$paged = get_query_var( 'paged' );
		$paged = intval( $paged );
		$qeseo_follow = "<meta name='robots' content='noindex,follow' />";
		$qeseo_nofollow = "<meta name='robots' content='noindex,nofollow' />";
		
		/* Date archives */
		if( is_date() ){
			$qeseo_value = $this->qeseo_options[ 'qeseo_date' ];
			
				if( $qeseo_value == 'ow_follow' ){
					return $qeseo_follow;
				}
				
				elseif( $qeseo_value == 'ow_nofollow' ){
					return $qeseo_nofollow;
				}
				
				elseif( ($qeseo_value == 'ow_follow_2nd_page') && ($paged > 1)  ){
					return $qeseo_follow;
				}
				
				elseif( ($qeseo_value == 'ow_nofollow_2nd_page') && ($paged > 1)  ){
					return $qeseo_nofollow;
				}
				
				else{ 
					return;
				}
			}
			
		/* Author archives */
		if( is_author() ){
			$qeseo_value = $this->qeseo_options[ 'qeseo_author' ];
			
			if( $qeseo_value == 'ow_follow' ){
				return $qeseo_follow;
			}elseif( $qeseo_value == 'ow_nofollow' ){
				return $qeseo_nofollow;
			}elseif( ($qeseo_value == 'ow_follow_2nd_page') && ($paged > 1)  ){
				return $qeseo_follow;
			}elseif( ($qeseo_value == 'ow_nofollow_2nd_page') && ($paged > 1)  ){
				return $qeseo_nofollow;
			}else{ 
				return;
			}
		}
			
		/* Category archives */
		if( is_category() ){
			$qeseo_value = $this->qeseo_options[ 'qeseo_category' ];
			
			if( $qeseo_value == 'ow_follow' ){
				return $qeseo_follow;
			}elseif( $qeseo_value == 'ow_nofollow' ){
				return $qeseo_nofollow;
			}elseif( ($qeseo_value == 'ow_follow_2nd_page') && ($paged > 1)  ){
				return $qeseo_follow;
			}elseif( ($qeseo_value == 'ow_nofollow_2nd_page') && ($paged > 1)  ){
				return $qeseo_nofollow;
			}else{ 
				return;
			}
		}
			
		/* Tag archives */
		if( is_tag() ){
			$qeseo_value = $this->qeseo_options[ 'qeseo_tag' ];
			
			if( $qeseo_value == 'ow_follow' ){
				return $qeseo_follow;
			}elseif( $qeseo_value == 'ow_nofollow' ){
				return $qeseo_nofollow;
			}elseif( ($qeseo_value == 'ow_follow_2nd_page') && ($paged > 1)  ){
				return $qeseo_follow;
			}elseif( ($qeseo_value == 'ow_nofollow_2nd_page') && ($paged > 1)  ){
				return $qeseo_nofollow;
			}else{ 
				return;
			}
		}
			
		/* Homepage archives */
		if( ( is_home() || is_front_page() ) && ( $paged > 1 ) ){
		$qeseo_value = $this->qeseo_options[ 'qeseo_homepage' ];
		
			if( ($qeseo_value == 'ow_follow_2nd_page') ){
				return $qeseo_follow;
			}elseif( ($qeseo_value == 'ow_nofollow_2nd_page') ){
				return $qeseo_nofollow;
			}else{ 
				return;
			}
		}
			
	}
		
	/* Add custom title tag */
	
	public function qeseo_add_custom_title_tag( $title ){
					
		if( ! is_singular() ){
			return $title;
		}
		
		global $post;
		$qeseo_custom_title = get_post_meta( $post->ID, '_qeseo_title_tag_meta_value', true  );
			
		if( ! isset( $qeseo_custom_title ) || empty( $qeseo_custom_title ) ){	
			return $title;
		}
			
		$qeseo_custom_title = sanitize_text_field( $qeseo_custom_title );
		$qeseo_custom_title = esc_html( $qeseo_custom_title );
		$title['title'] = $qeseo_custom_title;
		
		return $title;
	}
		
	/* Add custom Meta description tag */
	public function qeseo_add_custom_metades_tag(){
		
		/* Output custom meta description for single posts/pages/custom-post-types if set */
		if( is_singular() ){
			global $post;
			$qeseo_custom_metades = '';		
			$qeseo_custom_metades = get_post_meta( $post->ID, '_qeseo_metades_meta_value', true  ); 
			
			if( !empty( $qeseo_custom_metades ) ){
				$qeseo_custom_metades = strip_tags( $qeseo_custom_metades );
				$qeseo_custom_metades = sanitize_text_field( $qeseo_custom_metades );
				$qeseo_custom_metades = "<meta name='description' content='$qeseo_custom_metades' />";
				return $qeseo_custom_metades . "\n";
			}
		}
	}
	
	/* Add Meta description tag for category/tag pages if present */
	public function qeseo_meta_des_archives(){
		/* Output meta description for category/tag pages */
		if( is_category() || is_tag() || is_tax() ){
			$qeseo_term_id = get_queried_object_id();
			$qeseo_term_des = term_description( $qeseo_term_id );
			
			if( !empty( $qeseo_term_des ) ){
				$qeseo_term_des = strip_tags($qeseo_term_des);
				$qeseo_term_des = sanitize_text_field($qeseo_term_des);
				$qeseo_term_meta_des = "<meta name='description' content='$qeseo_term_des' />";
				return $qeseo_term_meta_des . "\n";
			}
		}
	}

	/* Remove unwanted tags */
	public function qeseo_remove_unwated_head_tags(){
		
		if( $this->qeseo_options['qeseo_remove_shortlink_tag'] ){
			remove_action('wp_head', 'wp_shortlink_wp_head');
		}
		
		if( $this->qeseo_options['qeseo_remove_nextprev_tag'] ){
			remove_action('wp_head', 'adjacent_posts_rel_link_wp_head');
		}
		
		if( $this->qeseo_options['qeseo_remove_wlwmanifest_tag'] ){
				remove_action('wp_head', 'wlwmanifest_link');
			}
		
		if( $this->qeseo_options['qeseo_remove_wp_generator_tag'] ){
				remove_action('wp_head', 'wp_generator');
			}

		if( $this->qeseo_options['qeseo_remove_feed_links_tag'] ){
					remove_action('wp_head', 'feed_links', 2);
					remove_action('wp_head', 'feed_links_extra', 3);
				}

		if( $this->qeseo_options['qeseo_remove_xml_rpc_tag'] ){
					remove_action('wp_head', 'rsd_link');
				}
	}

	/* Add Next and Prev rel tags to archive pages */
	
	public function qeseo_add_prev_next_archives(){
		$qeseo_nextprev_archives_option = $this->qeseo_options['qeseo_add_nextprev_archives_field'];
		
		if( $qeseo_nextprev_archives_option == 'yes' ){
			
			if( is_archive() || is_home() || is_front_page() ){
			global $wp_rewrite, $wp_query;
			
			/*Get pagination base for the permalink*/
			$basepaginate = esc_html( trailingslashit($wp_rewrite->pagination_base) );
			
			/*Get current page number*/
			$pnumber = intval( get_query_var( 'paged' ) );
			
			if($pnumber == 0){ $pnumber = 1; }
			$qeseo_perm_link = '';
			
			/*Get permalink for homepage*/
			if( is_home() || is_front_page() ){
				$qeseo_perm_link = get_option('siteurl');
			}
			
			/*Get permalink for category, tag and custom taxonomies (eg: Woocommerce category/tag archives) */
			if( is_category() || is_tag() || is_tax() ){
				$qeseo_tax_value_array = get_queried_object();
				$qeseo_tax_value = $qeseo_tax_value_array->taxonomy;
				$qeseo_tax_value = sanitize_text_field( $qeseo_tax_value );
				$qeseo_term_id = get_queried_object_id();
				$qeseo_perm_link = get_term_link( $qeseo_term_id, $qeseo_tax_value );
			}
			
			/* Get permalink for post type archive eg: Woocommerce shop pages */
			if( is_post_type_archive() ){
				$qeseo_post_type_object = get_queried_object();
				$qeseo_perm_link = sanitize_text_field( $qeseo_perm_link );
				$qeseo_perm_link = get_post_type_archive_link( $qeseo_post_type_object->name );
			}
			
			/*Get permalink for author archives*/
			if ( is_author() ){
				$qeseo_perm_link = get_author_posts_url( get_the_author_meta( 'ID' ) );
			}
			/*Get permalinks for date archives*/
			if(is_date()){
				if( is_day() ){
				$qeseo_perm_link =  get_day_link( get_post_time('Y'), get_post_time('m'), get_post_time('j') );
				}elseif( is_month() ){
				$qeseo_perm_link =  get_month_link( get_post_time('Y'), get_post_time('m') );
				}elseif( is_year() ){
				$qeseo_perm_link =  get_year_link( get_post_time('Y') );
				}
			}
			
			$qeseo_perm_link = esc_url( $qeseo_perm_link );	
			
			/*Construct the next and prev links*/
			if( ! empty( $qeseo_perm_link ) ){
					$qeseo_nxt_url = '';
					$qeseo_prev_url = '';
					$qeseo_canonical_link = '';
					
					if( $pnumber == 1  ){
						$qeseo_canonical_link = user_trailingslashit(trailingslashit($qeseo_perm_link));
						$qeseo_canonical_link = esc_url($qeseo_canonical_link);
						$qeseo_canonical_link = "<link rel='canonical' href='$qeseo_canonical_link'>\n";
					}else{
						$qeseo_canonical_link = user_trailingslashit(trailingslashit($qeseo_perm_link) . $basepaginate . $pnumber);
						$qeseo_canonical_link = esc_url($qeseo_canonical_link);
						$qeseo_canonical_link = "<link rel='canonical' href='$qeseo_canonical_link'>\n";
					}
					
					
					# Add rel="next" tag.
					if(get_next_posts_link() == true){
						$nxt_page_num = ($pnumber + 1);
						$qeseo_nxt_url = user_trailingslashit(trailingslashit($qeseo_perm_link) . $basepaginate . $nxt_page_num);
						$qeseo_nxt_url = esc_url($qeseo_nxt_url);
						$qeseo_nxt_url = "<link rel='next' href='$qeseo_nxt_url' /> \n";
						}
					# Add rel="prev" tag.	
					if(get_previous_posts_link() == true){
						$prev_page_num = ($pnumber - 1);
						if($pnumber == 2){$prev_page_num = ''; $basepaginate = '';}
						$qeseo_prev_url = user_trailingslashit(trailingslashit($qeseo_perm_link) . $basepaginate . $prev_page_num);
						$qeseo_prev_url = esc_url($qeseo_prev_url);
						$qeseo_prev_url = "<link rel='prev' href='$qeseo_prev_url' /> \n";
						}
						
					return $qeseo_canonical_link . $qeseo_nxt_url . $qeseo_prev_url;   	
					}
				}
			}else{
				return;
			}
		}
		
	/* Add prev and next tag to paginated single posts */		
	public function qeseo_prev_next_rel_paginated_posts(){
		
		if( ! is_single() ) return;
		
		$qeseo_nextprev_singlepages_option = $this->qeseo_options['qeseo_add_nextprev_singlepages_field'];
		
		if( $qeseo_nextprev_singlepages_option == 'yes' ){
			
			global $post;
						
			# 1: Count number of paginated pages.
			if( isset( $post->post_content ) ){
				$num_pages = intval ( ( substr_count( $post->post_content, '<!--nextpage-->' ) ) + 1 );
				} 

			# 2: Check if pagination exists on a single post.
			if($num_pages > 1){
				$qeseo_perm_link = esc_url( get_permalink() );
				$qeseo_prev_url = '';
				$qeseo_nxt_url = '';
				$qeseo_post_page_num = get_query_var('page'); 
				$qeseo_post_page_num = intval( $qeseo_post_page_num );
				if( $qeseo_post_page_num == 0 ){ $qeseo_post_page_num = 1; }
				
				# 3: Add rel="prev" meta tag.
				if( ($qeseo_post_page_num > 1) && ($qeseo_post_page_num <= $num_pages) ){
					$prev_page_num = ($qeseo_post_page_num - 1);
					if($qeseo_post_page_num == 2){$prev_page_num = '';}
					$qeseo_prev_url = user_trailingslashit(trailingslashit($qeseo_perm_link) . $prev_page_num);
					$qeseo_prev_url = esc_url($qeseo_prev_url);
					$qeseo_prev_url = "<link rel='prev' href='$qeseo_prev_url' /> \n";
					}
				
				# 4: Add rel="next" meta tag.
				if( ($qeseo_post_page_num >= 1) && ($qeseo_post_page_num < $num_pages) ){
					$nxt_page_num = ($qeseo_post_page_num + 1);
					$qeseo_nxt_url = user_trailingslashit(trailingslashit($qeseo_perm_link) . $nxt_page_num);
					$qeseo_nxt_url = esc_url($qeseo_nxt_url);
					$qeseo_nxt_url = "<link rel='next' href='$qeseo_nxt_url' /> \n";
					}
					
				return $qeseo_prev_url . $qeseo_nxt_url;
			}
		}
	}
	
	public function qeseo_pre_output_store(){
		/* Output robots meta tags for search/404/attachment pages */
		if( $this->qeseo_add_robots_tags() ){
			echo $this->qeseo_add_robots_tags();
			echo "\n";
		}
		
		/* Output robots meta tags for archive pages */
		if( $this->qeseo_robots_tag_archives() ){
			echo $this->qeseo_robots_tag_archives();
			echo "\n";
		}		
		
		/* Output custom meta description tag */
		if( $this->qeseo_add_custom_metades_tag() ){
			echo $this->qeseo_add_custom_metades_tag();
		}
		
		/* Output meta description tag for archives */
		if( $this->qeseo_meta_des_archives() ){
			echo $this->qeseo_meta_des_archives();
		}
		
		/* Output next/prev tag for paginted archives */
		if( $this->qeseo_add_prev_next_archives() ){
			echo $this->qeseo_add_prev_next_archives();
		}
			
		/* Output next/prev tag for paginted single post pages */
		if( $this->qeseo_prev_next_rel_paginated_posts() ){
			echo $this->qeseo_prev_next_rel_paginated_posts();
		}
		
	}
	
	/* Main Output */
	public function qeseo_print_all_values(){
		
		/* Check if output is present */
		ob_start();
			$this->qeseo_pre_output_store();
			$qeseo_output = ob_get_contents();
		ob_end_clean();
		
		/* Output data with comments */
		if( !empty( $qeseo_output ) ){
			echo "\n <!--Added by Quick and Easy SEO --> \n";
			$this->qeseo_pre_output_store();
			echo "<!--Added by Quick and Easy SEO --> \n\n";
		}		
	}
	
}
